@@ -16,7 +16,7 @@ Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
 
 # Version.
-our $VERSION = 0.13;
+our $VERSION = 0.14;
 
 # Ignore die signal.
 $SIG{__DIE__} = 'IGNORE';
@@ -94,7 +94,7 @@ with informations over HTTP.
 
  # Output like this:
  # Content-type: text/plain
- # 
+ #
  # #Error [script.pl:11] 1
 
 =head1 EXAMPLE2
@@ -111,7 +111,7 @@ with informations over HTTP.
 
  # Output like this:
  # Content-type: text/plain
- # 
+ #
  # #Error [script.pl:11] 1
 
 =head1 EXAMPLE3
@@ -146,22 +146,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Error::Pure>,
-L<Error::Pure::AllError>,
-L<Error::Pure::Always>,
-L<Error::Pure::Die>,
-L<Error::Pure::Error>,
-L<Error::Pure::ErrorList>,
-L<Error::Pure::HTTP::AllError>,
-L<Error::Pure::HTTP::Error>,
-L<Error::Pure::HTTP::JSON>,
-L<Error::Pure::HTTP::Print>,
-L<Error::Pure::JSON>,
-L<Error::Pure::NoDie>,
-L<Error::Pure::Output::JSON>,
-L<Error::Pure::Output::Text>,
-L<Error::Pure::Print>,
-L<Error::Pure::Utils>.
+=over
+
+=item L<Task::Error::Pure>
+
+Install the Error::Pure modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -175,10 +166,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © 2012-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.13
+0.14
 
 =cut
