@@ -5,12 +5,12 @@ use strict;
 use warnings;
 
 # Modules.
-use Error::Pure::HTTP::Error qw(err);
+use Error::Pure::HTTP::ErrorList qw(err);
 
 # Error.
 err '1', '2', '3';
 
 # Output like this:
 # Content-type: text/plain
-# 
-# #Error [script.pl:12] 1
\ No newline at end of file
+#
+# #Error [script.pl:11] 1
\ No newline at end of file
