@@ -5,12 +5,12 @@ use strict;
 use warnings;
 
 # Modules.
-use Error::Pure::HTTP::Print qw(err);
+use Error::Pure::HTTP::Error qw(err);
 
 # Error.
 err '1';
 
-# Output:
+# Output like this:
 # Content-type: text/plain
 #
-# 1
\ No newline at end of file
+# #Error [script.pl:12] 1
\ No newline at end of file
